#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
doc:
"""
import json

UNICODE_JSON = True,
COMPACT_JSON = True,

# `separators` argument to `json.dumps()` differs between 2.x and 3.x
# See: https://bugs.python.org/issue22767
SHORT_SEPARATORS = (',', ':')
LONG_SEPARATORS = (', ', ': ')
INDENT_SEPARATORS = (',', ': ')


def dumps(data, indent=None,
          ensure_ascii=UNICODE_JSON,
          allow_nan=not COMPACT_JSON,
          separators=INDENT_SEPARATORS,
          )->str:
    json_str = json.dumps(
        data, cls=json.JSONEncoder,
        indent=indent,
        ensure_ascii=ensure_ascii,
        allow_nan=allow_nan,
        separators=separators
    )
    return json_str


def main():
    data = {
        'name': 'compile',
        'params': {
            'bdg': '1758431528494305280',
            'is_publish': True,
            'token': 'aa.bb.Fx93qRLDHsrQPp8ab1C6Lg4_pnM'
        }
    }
    ret = dumps(data)
    print(ret)
    pass


if __name__ == '__main__':
    main()



__version__ = '0.1.5'

from .tools import (
    underline2hump, hump2underline,
    json_hump2underline, json_underline2hump, json_str_underline2hump,
)
from .render import (
    hump_json_renderer_byte,
    hump_json_renderer_str,
)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['humplib']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'humplib',
    'version': '0.1.5',
    'description': 'a hump to underline tool',
    'long_description': None,
    'author': 'huoyinghui',
    'author_email': 'yhhuo@yunjinginc.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/pydtools/humplib/',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*',
}


setup(**setup_kwargs)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
doc:
参考drf JSONRenderer/ HumpJSONRenderer

"""
from humplib.tools import json_underline2hump


def hump_json_renderer_str(data: dict=None)->str:
    """
    Convert to camel case and use double quotes
    1
    b'{"a": 1,"aB": 1}'

    :param data:
    :return:
    """
    ret = json_underline2hump(json_obj=data)
    # We always fully escape \u2028 and \u2029 to ensure we output JSON
    # that is a strict javascript subset.
    # See: http://timelessrepo.com/json-isnt-a-javascript-subset
    ret = ret.replace('\u2028', '\\u2028').replace('\u2029', '\\u2029')
    return ret


def hump_json_renderer_byte(data: dict=None):
    """

    :param data:
    :return:
    """
    ret_str = hump_json_renderer_str(data=data)
    return ret_str.encode()


def main():
    data = {
        'name': 'compile',
        'params': {
            'bdg': '1758431528494305280',
            'is_publish': True,
            'token': 'aa.bb.Fx93qRLDHsrQPp8ab1C6Lg4_pnM'
        }
    }
    ret = hump_json_renderer_str(data)
    print(ret)
    pass


if __name__ == '__main__':
    main()

